@@ -256,6 +256,15 @@ try {
             echo json_encode($result);
             exit;
 
+        case 'check_force_https_status':
+            if (empty($_POST['site_id']) || !is_numeric($_POST['site_id'])) {
+                throw new Exception('Valid numeric site ID required');
+            }
+            $result = $wpManager->checkForceHttpsStatus((int)$_POST['site_id']);
+            ob_clean(); // Clear buffer before output
+            echo json_encode($result);
+            exit;
+
         case 'force_https':
             if (empty($_POST['site_id']) || !is_numeric($_POST['site_id'])) {
                 throw new Exception('Valid numeric site ID required');
@@ -265,6 +274,15 @@ try {
             echo json_encode($result);
             exit;
 
+        case 'disable_force_https':
+            if (empty($_POST['site_id']) || !is_numeric($_POST['site_id'])) {
+                throw new Exception('Valid numeric site ID required');
+            }
+            $result = $wpManager->disableForceHttps((int)$_POST['site_id']);
+            ob_clean(); // Clear buffer before output
+            echo json_encode($result);
+            exit;
+
         case 'security_scan':
             if (empty($_POST['site_id'])) {
                 throw new Exception('Site ID required');
