@@ -335,7 +335,10 @@ class haproxy_manager {
     
     /**
      * Store domain configuration in database
-     * 
+     *
+     * Preserves existing SSL settings (ssl_enabled, ssl_certificate_path, ssl_last_renewal)
+     * when updating backend configuration. Only updates backend_name and server list.
+     *
      * @param string $domain Domain name
      * @param string $backend_name Backend name
      * @param array $servers Backend servers
@@ -343,10 +346,12 @@ class haproxy_manager {
     private function storeDomainConfiguration($domain, $backend_name, $servers) {
         try {
             // Insert or update domain configuration
+            // Note: ON DUPLICATE KEY UPDATE intentionally only updates backend_name and updated_at
+            // to preserve SSL settings (ssl_enabled, ssl_certificate_path, ssl_last_renewal)
             $stmt = $this->db->prepare("
-                INSERT INTO whp.haproxy_domains (domain_name, backend_name) 
-                VALUES (?, ?) 
-                ON DUPLICATE KEY UPDATE 
+                INSERT INTO whp.haproxy_domains (domain_name, backend_name)
+                VALUES (?, ?)
+                ON DUPLICATE KEY UPDATE
                 backend_name = VALUES(backend_name),
                 updated_at = CURRENT_TIMESTAMP
             ");
@@ -523,7 +528,7 @@ class haproxy_manager {
             foreach ($site_domains as $site_domain) {
                 $fqdn = $site_domain['fqdn'] ?: $site_domain['domain_name']; // Use FQDN if available, fallback to domain_name
                 $servers = [];
-                
+
                 // Add each container as a server
                 foreach ($containers as $container) {
                     // Generate container name from primary domain and container number
@@ -539,14 +544,9 @@ class haproxy_manager {
                         'options' => $options
                     ];
                 }
-                
-                // Remove existing configuration first, then add new one
-                $remove_result = $this->removeDomain($fqdn);
-                if (!$remove_result['success']) {
-                    error_log("HAProxy Manager: Failed to remove existing domain configuration for $fqdn: " . $remove_result['error']);
-                }
-                
-                // Add FQDN to HAProxy with new server configuration
+
+                // Update FQDN configuration in HAProxy with new server configuration
+                // Note: This preserves SSL settings via ON DUPLICATE KEY UPDATE in storeDomainConfiguration()
                 $result = $this->addDomain($fqdn, $servers);
                 $results[$fqdn] = $result;
             }
