@@ -219,7 +219,7 @@ $pdo = $MySQLMgmt->getMySQLConnection();
     </div>
 
     <script>
-        const nonce = '<?php echo $_SESSION['nonce'] ?? ''; ?>';
+        const nonce = '<?php echo get_csrf_token(); ?>';
         let currentImportId = null;
         let statusCheckInterval = null;
         let availableBackups = [];
@@ -243,10 +243,10 @@ $pdo = $MySQLMgmt->getMySQLConnection();
                     method: 'POST',
                     headers: {
                         'Content-Type': 'application/x-www-form-urlencoded',
+                        'X-CSRF-Token': nonce
                     },
                     body: new URLSearchParams({
-                        action: 'list_users',
-                        nonce: nonce
+                        action: 'list_users'
                     })
                 });
 
@@ -287,8 +287,7 @@ $pdo = $MySQLMgmt->getMySQLConnection();
         async function refreshBackupFiles() {
             try {
                 const params = {
-                    action: 'get_backup_files',
-                    nonce: nonce
+                    action: 'get_backup_files'
                 };
                 
                 <?php if (AUTH_USER === 'root'): ?>
@@ -308,6 +307,7 @@ $pdo = $MySQLMgmt->getMySQLConnection();
                     method: 'POST',
                     headers: {
                         'Content-Type': 'application/x-www-form-urlencoded',
+                        'X-CSRF-Token': nonce
                     },
                     body: new URLSearchParams(params)
                 });
@@ -382,6 +382,7 @@ $pdo = $MySQLMgmt->getMySQLConnection();
                     method: 'POST',
                     headers: {
                         'Content-Type': 'application/x-www-form-urlencoded',
+                        'X-CSRF-Token': nonce
                     },
                     body: new URLSearchParams({
                         action: 'select_backup',
@@ -419,8 +420,7 @@ $pdo = $MySQLMgmt->getMySQLConnection();
             try {
                 const params = {
                     action: 'start_import',
-                    backup_file: backupFilePath,
-                    nonce: nonce
+                    backup_file: backupFilePath
                 };
                 
                 <?php if (AUTH_USER === 'root'): ?>
@@ -431,6 +431,7 @@ $pdo = $MySQLMgmt->getMySQLConnection();
                     method: 'POST',
                     headers: {
                         'Content-Type': 'application/x-www-form-urlencoded',
+                        'X-CSRF-Token': nonce
                     },
                     body: new URLSearchParams(params)
                 });
@@ -470,11 +471,11 @@ $pdo = $MySQLMgmt->getMySQLConnection();
                     method: 'POST',
                     headers: {
                         'Content-Type': 'application/x-www-form-urlencoded',
+                        'X-CSRF-Token': nonce
                     },
                     body: new URLSearchParams({
                         action: 'get_import_status',
-                        import_id: currentImportId,
-                        nonce: nonce
+                        import_id: currentImportId
                     })
                 });
 
